from setuptools import setup

setup(
    name='blueberrymath',
    version='0.1.1',
    description='Open Source Mathematical Package',
    url='https://github.com/faustotnc/BlueBerryMath',
    author='Fausto German',
    author_email='faustotnc@gmail.com',
    license='MIT',
    packages=['blueberrymath'],
    install_requires=['typing'],
    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: MIT License',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
)
